Welcome to GsuiteToMd’s documentation! — GsuiteToMd 0.99 documentation

# Welcome to GsuiteToMd’s documentation!

GsuiteToMd is a library built on top of PyDrive that offers a simple way to convert Documents store in Google Drive in markdown.

# How to install

You can install GsuiteToMd with regular `pip` command.

    $ pip install GsuiteToMd

- How to install
  - Basic example
- gstomd package
  - gstomd.__main__ module
  - gstomd.convert module
  - gstomd.node module
  - gstomd.gfolder module
  - gstomd.gdoc module
  - gstomd.utils module

# Indices and tables

- Index

- Module Index

- Search Page